pub async fn insert_email_delivery(
conn: &mut PgConnection,
user_id: Uuid,
email_template_id: Uuid,
) -> ModelResult<Uuid>Expand description
Inserts an email delivery; fails if the user or email template is soft-deleted.
pub async fn insert_email_delivery(
conn: &mut PgConnection,
user_id: Uuid,
email_template_id: Uuid,
) -> ModelResult<Uuid>Inserts an email delivery; fails if the user or email template is soft-deleted.